import datetime

from eolymp.course import assignment_pb2 as _assignment_pb2
from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Module(_message.Message):
    __slots__ = ("id", "url", "draft", "extra", "weight", "name", "image_url", "index", "description", "start_after", "complete_before", "duration", "progress", "assignment")
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        UNKNOWN_EXTRA: _ClassVar[Module.Extra]
        DESCRIPTION_VALUE: _ClassVar[Module.Extra]
        DESCRIPTION_RENDER: _ClassVar[Module.Extra]
        PROGRESS: _ClassVar[Module.Extra]
        ASSIGNMENT: _ClassVar[Module.Extra]
    UNKNOWN_EXTRA: Module.Extra
    DESCRIPTION_VALUE: Module.Extra
    DESCRIPTION_RENDER: Module.Extra
    PROGRESS: Module.Extra
    ASSIGNMENT: Module.Extra
    class Progress(_message.Message):
        __slots__ = ("status", "percentage", "grade", "grade_automatic", "grade_override", "excused", "start_after", "complete_before", "duration", "upsolve", "assigned_at", "started_at", "completed_at")
        STATUS_FIELD_NUMBER: _ClassVar[int]
        PERCENTAGE_FIELD_NUMBER: _ClassVar[int]
        GRADE_FIELD_NUMBER: _ClassVar[int]
        GRADE_AUTOMATIC_FIELD_NUMBER: _ClassVar[int]
        GRADE_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
        EXCUSED_FIELD_NUMBER: _ClassVar[int]
        START_AFTER_FIELD_NUMBER: _ClassVar[int]
        COMPLETE_BEFORE_FIELD_NUMBER: _ClassVar[int]
        DURATION_FIELD_NUMBER: _ClassVar[int]
        UPSOLVE_FIELD_NUMBER: _ClassVar[int]
        ASSIGNED_AT_FIELD_NUMBER: _ClassVar[int]
        STARTED_AT_FIELD_NUMBER: _ClassVar[int]
        COMPLETED_AT_FIELD_NUMBER: _ClassVar[int]
        status: _assignment_pb2.Assignment.Status
        percentage: float
        grade: int
        grade_automatic: int
        grade_override: int
        excused: bool
        start_after: _timestamp_pb2.Timestamp
        complete_before: _timestamp_pb2.Timestamp
        duration: int
        upsolve: bool
        assigned_at: _timestamp_pb2.Timestamp
        started_at: _timestamp_pb2.Timestamp
        completed_at: _timestamp_pb2.Timestamp
        def __init__(self, status: _Optional[_Union[_assignment_pb2.Assignment.Status, str]] = ..., percentage: _Optional[float] = ..., grade: _Optional[int] = ..., grade_automatic: _Optional[int] = ..., grade_override: _Optional[int] = ..., excused: bool = ..., start_after: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., complete_before: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ..., upsolve: bool = ..., assigned_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., started_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., completed_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    DRAFT_FIELD_NUMBER: _ClassVar[int]
    EXTRA_FIELD_NUMBER: _ClassVar[int]
    WEIGHT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IMAGE_URL_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    START_AFTER_FIELD_NUMBER: _ClassVar[int]
    COMPLETE_BEFORE_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    PROGRESS_FIELD_NUMBER: _ClassVar[int]
    ASSIGNMENT_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    draft: bool
    extra: bool
    weight: float
    name: str
    image_url: str
    index: int
    description: _content_pb2.Content
    start_after: _timestamp_pb2.Timestamp
    complete_before: _timestamp_pb2.Timestamp
    duration: int
    progress: Module.Progress
    assignment: _assignment_pb2.Assignment
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., draft: bool = ..., extra: bool = ..., weight: _Optional[float] = ..., name: _Optional[str] = ..., image_url: _Optional[str] = ..., index: _Optional[int] = ..., description: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., start_after: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., complete_before: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., duration: _Optional[int] = ..., progress: _Optional[_Union[Module.Progress, _Mapping]] = ..., assignment: _Optional[_Union[_assignment_pb2.Assignment, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/atlas/statement_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/atlas/statement_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import statement_pb2 as eolymp_dot_atlas_dot_statement__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/atlas/statement_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1c\x65olymp/atlas/statement.proto\"|\n\x15StatementChangedEvent\x12\x12\n\nproblem_id\x18\x01 \x01(\t\x12\'\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\x12&\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"\x83\x01\n\x13ListStatementsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06render\x18\x02 \x01(\x08\x12\x0f\n\x07version\x18\x64 \x01(\r\x12-\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1d.eolymp.atlas.Statement.Extra\"M\n\x14ListStatementsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.atlas.Statement\"m\n\x18TranslateStatementsInput\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x03(\t\x12\x18\n\x10target_automatic\x18\x03 \x01(\x08\x12\x17\n\x0foverride_manual\x18\x04 \x01(\x08\"+\n\x19TranslateStatementsOutput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"}\n\x16\x44\x65scribeStatementInput\x12\x14\n\x0cstatement_id\x18\x02 \x01(\t\x12\x0e\n\x06render\x18\x03 \x01(\x08\x12\x0f\n\x07version\x18\x64 \x01(\r\x12,\n\x05\x65xtra\x18\n \x03(\x0e\x32\x1d.eolymp.atlas.Statement.Extra\"E\n\x17\x44\x65scribeStatementOutput\x12*\n\tstatement\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"u\n\x14LookupStatementInput\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x0e\n\x06render\x18\x03 \x01(\x08\x12\x0f\n\x07version\x18\x64 \x01(\r\x12,\n\x05\x65xtra\x18\n \x03(\x0e\x32\x1d.eolymp.atlas.Statement.Extra\"C\n\x15LookupStatementOutput\x12*\n\tstatement\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"C\n\x15PreviewStatementInput\x12*\n\tstatement\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"D\n\x16PreviewStatementOutput\x12*\n\tstatement\x18\x01 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"B\n\x14\x43reateStatementInput\x12*\n\tstatement\x18\x02 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"-\n\x15\x43reateStatementOutput\x12\x14\n\x0cstatement_id\x18\x01 \x01(\t\"\x86\x01\n\x14UpdateStatementInput\x12,\n\x05patch\x18\n \x03(\x0e\x32\x1d.eolymp.atlas.Statement.Patch\x12\x14\n\x0cstatement_id\x18\x02 \x01(\t\x12*\n\tstatement\x18\x03 \x01(\x0b\x32\x17.eolymp.atlas.Statement\"\x17\n\x15UpdateStatementOutput\",\n\x14\x44\x65leteStatementInput\x12\x14\n\x0cstatement_id\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteStatementOutput\",\n\x14\x45xportStatementInput\x12\x14\n\x0cstatement_id\x18\x02 \x01(\t\"-\n\x15\x45xportStatementOutput\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t2\xe4\x0b\n\x10StatementService\x12\x99\x01\n\x0f\x43reateStatement\x12\".eolymp.atlas.CreateStatementInput\x1a#.eolymp.atlas.CreateStatementOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\r\x1a\x0b/statements\x12\xa8\x01\n\x0fUpdateStatement\x12\".eolymp.atlas.UpdateStatementInput\x1a#.eolymp.atlas.UpdateStatementOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1c\x1a\x1a/statements/{statement_id}\x12\xa8\x01\n\x0f\x44\x65leteStatement\x12\".eolymp.atlas.DeleteStatementInput\x1a#.eolymp.atlas.DeleteStatementOutput\"L\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x1c*\x1a/statements/{statement_id}\x12\xad\x01\n\x11\x44\x65scribeStatement\x12$.eolymp.atlas.DescribeStatementInput\x1a%.eolymp.atlas.DescribeStatementOutput\"K\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x1c\x12\x1a/statements/{statement_id}\x12\x97\x01\n\x0fLookupStatement\x12\".eolymp.atlas.LookupStatementInput\x1a#.eolymp.atlas.LookupStatementOutput\";\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\x0c\x12\n/translate\x12\x98\x01\n\x10PreviewStatement\x12#.eolymp.atlas.PreviewStatementInput\x1a$.eolymp.atlas.PreviewStatementOutput\"9\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\n\"\x08/renders\x12\x95\x01\n\x0eListStatements\x12!.eolymp.atlas.ListStatementsInput\x1a\".eolymp.atlas.ListStatementsOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02\r\x12\x0b/statements\x12\xaf\x01\n\x13TranslateStatements\x12&.eolymp.atlas.TranslateStatementsInput\x1a\'.eolymp.atlas.TranslateStatementsOutput\"G\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\x82\xd3\xe4\x93\x02\x17\"\x15/statements:translate\x12\xae\x01\n\x0f\x45xportStatement\x12\".eolymp.atlas.ExportStatementInput\x1a#.eolymp.atlas.ExportStatementOutput\"R\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\x82\xd3\xe4\x93\x02#\"!/statements/{statement_id}/exportB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.statement_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _globals['_STATEMENTSERVICE'].methods_by_name['CreateStatement']._loaded_options = None
  _globals['_STATEMENTSERVICE'].methods_by_name['CreateStatement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\r\032\013/statements'
  _globals['_STATEMENTSERVICE'].methods_by_name['UpdateStatement']._loaded_options = None
  _globals['_STATEMENTSERVICE'].methods_by_name['UpdateStatement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\034\032\032/statements/{statement_id}'
  _globals['_STATEMENTSERVICE'].methods_by_name['DeleteStatement']._loaded_options = None
  _globals['_STATEMENTSERVICE'].methods_by_name['DeleteStatement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\034*\032/statements/{statement_id}'
  _globals['_STATEMENTSERVICE'].methods_by_name['DescribeStatement']._loaded_options = None
  _globals['_STATEMENTSERVICE'].methods_by_name['DescribeStatement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\034\022\032/statements/{statement_id}'
  _globals['_STATEMENTSERVICE'].methods_by_name['LookupStatement']._loaded_options = None
  _globals['_STATEMENTSERVICE'].methods_by_name['LookupStatement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\014\022\n/translate'
  _globals['_STATEMENTSERVICE'].methods_by_name['PreviewStatement']._loaded_options = None
  _globals['_STATEMENTSERVICE'].methods_by_name['PreviewStatement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\n\"\010/renders'
  _globals['_STATEMENTSERVICE'].methods_by_name['ListStatements']._loaded_options = None
  _globals['_STATEMENTSERVICE'].methods_by_name['ListStatements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002\r\022\013/statements'
  _globals['_STATEMENTSERVICE'].methods_by_name['TranslateStatements']._loaded_options = None
  _globals['_STATEMENTSERVICE'].methods_by_name['TranslateStatements']._serialized_options = b'\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\343\n\027\212\343\n\023atlas:problem:write\202\323\344\223\002\027\"\025/statements:translate'
  _globals['_STATEMENTSERVICE'].methods_by_name['ExportStatement']._loaded_options = None
  _globals['_STATEMENTSERVICE'].methods_by_name['ExportStatement']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\343\n\026\212\343\n\022atlas:problem:read\202\323\344\223\002#\"!/statements/{statement_id}/export'
  _globals['_STATEMENTCHANGEDEVENT']._serialized_start=183
  _globals['_STATEMENTCHANGEDEVENT']._serialized_end=307
  _globals['_LISTSTATEMENTSINPUT']._serialized_start=310
  _globals['_LISTSTATEMENTSINPUT']._serialized_end=441
  _globals['_LISTSTATEMENTSOUTPUT']._serialized_start=443
  _globals['_LISTSTATEMENTSOUTPUT']._serialized_end=520
  _globals['_TRANSLATESTATEMENTSINPUT']._serialized_start=522
  _globals['_TRANSLATESTATEMENTSINPUT']._serialized_end=631
  _globals['_TRANSLATESTATEMENTSOUTPUT']._serialized_start=633
  _globals['_TRANSLATESTATEMENTSOUTPUT']._serialized_end=676
  _globals['_DESCRIBESTATEMENTINPUT']._serialized_start=678
  _globals['_DESCRIBESTATEMENTINPUT']._serialized_end=803
  _globals['_DESCRIBESTATEMENTOUTPUT']._serialized_start=805
  _globals['_DESCRIBESTATEMENTOUTPUT']._serialized_end=874
  _globals['_LOOKUPSTATEMENTINPUT']._serialized_start=876
  _globals['_LOOKUPSTATEMENTINPUT']._serialized_end=993
  _globals['_LOOKUPSTATEMENTOUTPUT']._serialized_start=995
  _globals['_LOOKUPSTATEMENTOUTPUT']._serialized_end=1062
  _globals['_PREVIEWSTATEMENTINPUT']._serialized_start=1064
  _globals['_PREVIEWSTATEMENTINPUT']._serialized_end=1131
  _globals['_PREVIEWSTATEMENTOUTPUT']._serialized_start=1133
  _globals['_PREVIEWSTATEMENTOUTPUT']._serialized_end=1201
  _globals['_CREATESTATEMENTINPUT']._serialized_start=1203
  _globals['_CREATESTATEMENTINPUT']._serialized_end=1269
  _globals['_CREATESTATEMENTOUTPUT']._serialized_start=1271
  _globals['_CREATESTATEMENTOUTPUT']._serialized_end=1316
  _globals['_UPDATESTATEMENTINPUT']._serialized_start=1319
  _globals['_UPDATESTATEMENTINPUT']._serialized_end=1453
  _globals['_UPDATESTATEMENTOUTPUT']._serialized_start=1455
  _globals['_UPDATESTATEMENTOUTPUT']._serialized_end=1478
  _globals['_DELETESTATEMENTINPUT']._serialized_start=1480
  _globals['_DELETESTATEMENTINPUT']._serialized_end=1524
  _globals['_DELETESTATEMENTOUTPUT']._serialized_start=1526
  _globals['_DELETESTATEMENTOUTPUT']._serialized_end=1549
  _globals['_EXPORTSTATEMENTINPUT']._serialized_start=1551
  _globals['_EXPORTSTATEMENTINPUT']._serialized_end=1595
  _globals['_EXPORTSTATEMENTOUTPUT']._serialized_start=1597
  _globals['_EXPORTSTATEMENTOUTPUT']._serialized_end=1642
  _globals['_STATEMENTSERVICE']._serialized_start=1645
  _globals['_STATEMENTSERVICE']._serialized_end=3153
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/certificate/certificate.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/certificate/certificate.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$eolymp/certificate/certificate.proto\x12\x12\x65olymp.certificate\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf6\x02\n\x0b\x43\x65rtificate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x11\n\ttarget_id\x18\x03 \x01(\t\x12\x18\n\x10verification_url\x18\x14 \x01(\t\x12\x14\n\x0c\x64ownload_url\x18\x15 \x01(\t\x12\x10\n\x08html_url\x18\x16 \x01(\t\x12\x0e\n\x06locale\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x43\n\nattributes\x18\x06 \x03(\x0b\x32/.eolymp.certificate.Certificate.AttributesEntry\x12-\n\tissued_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpires_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x39Z7github.com/eolymp/go-sdk/eolymp/certificate;certificateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.certificate.certificate_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/eolymp/go-sdk/eolymp/certificate;certificate'
  _globals['_CERTIFICATE_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_CERTIFICATE_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_CERTIFICATE']._serialized_start=94
  _globals['_CERTIFICATE']._serialized_end=468
  _globals['_CERTIFICATE_ATTRIBUTESENTRY']._serialized_start=419
  _globals['_CERTIFICATE_ATTRIBUTESENTRY']._serialized_end=468
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/commerce/shopping_cart.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/commerce/shopping_cart.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.commerce import address_pb2 as eolymp_dot_commerce_dot_address__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/commerce/shopping_cart.proto\x12\x0f\x65olymp.commerce\x1a\x1d\x65olymp/commerce/address.proto\"\x90\x04\n\x0cShoppingCart\x12\n\n\x02id\x18\x01 \x01(\t\x12\x31\n\x05items\x18\n \x03(\x0b\x32\".eolymp.commerce.ShoppingCart.Item\x12\x31\n\x0f\x62illing_address\x18( \x01(\x0b\x32\x18.eolymp.commerce.Address\x12\x32\n\x10shipping_address\x18) \x01(\x0b\x32\x18.eolymp.commerce.Address\x12 \n\x18\x62illing_same_as_shipping\x18* \x01(\x08\x12\x10\n\x08\x63urrency\x18\x14 \x01(\t\x12\x14\n\x0ctotal_amount\x18\x15 \x01(\r\x12\x17\n\x0fshipping_amount\x18\x16 \x01(\r\x12\x17\n\x0f\x64iscount_amount\x18\x17 \x01(\r\x12\x12\n\ntax_amount\x18\x18 \x01(\r\x12\x10\n\x08tax_rate\x18\x19 \x01(\r\x12\x10\n\x08tax_note\x18\x1a \x01(\t\x12\x13\n\x0bgrand_total\x18\x1e \x01(\r\x1a\x90\x01\n\x04Item\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproduct_id\x18\x02 \x01(\t\x12\x12\n\nvariant_id\x18\x03 \x01(\t\x12\x10\n\x08quantity\x18\n \x01(\r\x12\x13\n\x0bunit_amount\x18\x15 \x01(\r\x12\x14\n\x0ctotal_amount\x18\x16 \x01(\r\x12\x17\n\x0f\x64iscount_amount\x18\x17 \x01(\rB3Z1github.com/eolymp/go-sdk/eolymp/commerce;commerceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.commerce.shopping_cart_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/commerce;commerce'
  _globals['_SHOPPINGCART']._serialized_start=88
  _globals['_SHOPPINGCART']._serialized_end=616
  _globals['_SHOPPINGCART_ITEM']._serialized_start=472
  _globals['_SHOPPINGCART_ITEM']._serialized_end=616
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.discussion import thread_pb2 as _thread_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeThreadInput(_message.Message):
    __slots__ = ("locale",)
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    locale: str
    def __init__(self, locale: _Optional[str] = ...) -> None: ...

class DescribeThreadOutput(_message.Message):
    __slots__ = ("thread",)
    THREAD_FIELD_NUMBER: _ClassVar[int]
    thread: _thread_pb2.Thread
    def __init__(self, thread: _Optional[_Union[_thread_pb2.Thread, _Mapping]] = ...) -> None: ...

class VoteThreadInput(_message.Message):
    __slots__ = ("message_id", "vote")
    MESSAGE_ID_FIELD_NUMBER: _ClassVar[int]
    VOTE_FIELD_NUMBER: _ClassVar[int]
    message_id: str
    vote: int
    def __init__(self, message_id: _Optional[str] = ..., vote: _Optional[int] = ...) -> None: ...

class VoteThreadOutput(_message.Message):
    __slots__ = ("vote_count",)
    VOTE_COUNT_FIELD_NUMBER: _ClassVar[int]
    vote_count: int
    def __init__(self, vote_count: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/activity_graph_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/activity_graph_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-eolymp/community/activity_graph_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x83\x01\n\x1a\x44\x65scribeActivityGraphInput\x12)\n\x05\x61\x66ter\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06metric\x18\x03 \x01(\t\"@\n\x1b\x44\x65scribeActivityGraphOutput\x12\x0e\n\x06values\x18\x01 \x03(\x05\x12\x11\n\tmax_value\x18\n \x01(\x05\x32\xd2\x01\n\x14\x41\x63tivityGraphService\x12\xb9\x01\n\x15\x44\x65scribeActivityGraph\x12,.eolymp.community.DescribeActivityGraphInput\x1a-.eolymp.community.DescribeActivityGraphOutput\"C\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x11\x12\x0f/activity-graphB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.activity_graph_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_ACTIVITYGRAPHSERVICE'].methods_by_name['DescribeActivityGraph']._loaded_options = None
  _globals['_ACTIVITYGRAPHSERVICE'].methods_by_name['DescribeActivityGraph']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\021\022\017/activity-graph'
  _globals['_DESCRIBEACTIVITYGRAPHINPUT']._serialized_start=200
  _globals['_DESCRIBEACTIVITYGRAPHINPUT']._serialized_end=331
  _globals['_DESCRIBEACTIVITYGRAPHOUTPUT']._serialized_start=333
  _globals['_DESCRIBEACTIVITYGRAPHOUTPUT']._serialized_end=397
  _globals['_ACTIVITYGRAPHSERVICE']._serialized_start=400
  _globals['_ACTIVITYGRAPHSERVICE']._serialized_end=610
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/universe/billing_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/universe/billing_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.commerce import invoice_pb2 as eolymp_dot_commerce_dot_invoice__pb2
from eolymp.universe import billing_pb2 as eolymp_dot_universe_dot_billing__pb2
from eolymp.universe import plan_pb2 as eolymp_dot_universe_dot_plan__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/universe/billing_service.proto\x12\x0f\x65olymp.universe\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1d\x65olymp/commerce/invoice.proto\x1a\x1d\x65olymp/universe/billing.proto\x1a\x1a\x65olymp/universe/plan.proto\"!\n\x1f\x44\x65scribeBillingInformationInput\"V\n DescribeBillingInformationOutput\x12\x32\n\x04info\x18\x01 \x01(\x0b\x32$.eolymp.universe.Billing.Information\"S\n\x1dUpdateBillingInformationInput\x12\x32\n\x04info\x18\x01 \x01(\x0b\x32$.eolymp.universe.Billing.Information\" \n\x1eUpdateBillingInformationOutput\"\x1b\n\x19\x44\x65scribeSubscriptionInput\"\x8d\x01\n\x1a\x44\x65scribeSubscriptionOutput\x12\x36\n\x07\x63urrent\x18\x01 \x01(\x0b\x32%.eolymp.universe.Billing.Subscription\x12\x37\n\x08upcoming\x18\x02 \x01(\x0b\x32%.eolymp.universe.Billing.Subscription\"M\n\x17\x43reateSubscriptionInput\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x12\n\nvariant_id\x18\x02 \x01(\t\x12\r\n\x05seats\x18\x03 \x01(\r\"0\n\x18\x43reateSubscriptionOutput\x12\x14\n\x0c\x63heckout_url\x18\x01 \x01(\t\"M\n\x17UpdateSubscriptionInput\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x12\n\nvariant_id\x18\x02 \x01(\t\x12\r\n\x05seats\x18\x03 \x01(\r\"\x1a\n\x18UpdateSubscriptionOutput\"\x19\n\x17\x43\x61ncelSubscriptionInput\"\x1a\n\x18\x43\x61ncelSubscriptionOutput\"B\n\x1bStartSubscriptionTrialInput\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x12\n\nvariant_id\x18\x02 \x01(\t\"\x1e\n\x1cStartSubscriptionTrialOutput\"\x1b\n\x19\x45ndSubscriptionTrialInput\"\x1c\n\x1a\x45ndSubscriptionTrialOutput\"_\n\x19SimulateSubscriptionInput\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\x12\x12\n\nvariant_id\x18\x02 \x01(\t\x12\r\n\x05seats\x18\x03 \x01(\r\x12\x0e\n\x06\x63oupon\x18\n \x01(\t\"n\n\x1aSimulateSubscriptionOutput\x12%\n\x03\x64ue\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Invoice\x12)\n\x07invoice\x18\x02 \x01(\x0b\x32\x18.eolymp.commerce.Invoice\"K\n\x15\x43reatePortalLinkInput\x12\x0c\n\x04\x66low\x18\x01 \x01(\t\x12\x10\n\x08\x62\x61\x63k_url\x18\x02 \x01(\t\x12\x12\n\nreturn_url\x18\x03 \x01(\t\"-\n\x16\x43reatePortalLinkOutput\x12\x13\n\x0bportal_link\x18\x01 \x01(\t\"\x16\n\x14UpcomingInvoiceInput\"B\n\x15UpcomingInvoiceOutput\x12)\n\x07invoice\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Invoice\"*\n\x14\x44\x65scribeInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\"B\n\x15\x44\x65scribeInvoiceOutput\x12)\n\x07invoice\x18\x01 \x01(\x0b\x32\x18.eolymp.commerce.Invoice\"%\n\x0fPayInvoiceInput\x12\x12\n\ninvoice_id\x18\x01 \x01(\t\"(\n\x10PayInvoiceOutput\x12\x14\n\x0c\x63heckout_url\x18\x01 \x01(\t\"@\n\x11ListInvoicesInput\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0e\n\x06\x62\x65\x66ore\x18\r \x01(\t\"L\n\x12ListInvoicesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.commerce.Invoice\"\x86\x01\n\x17ListAvailablePlansInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0e\n\x06locale\x18\x65 \x01(\t\x12\x10\n\x08\x63urrency\x18\x66 \x01(\t\x12+\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1b.eolymp.universe.Plan.Extra\"O\n\x18ListAvailablePlansOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.universe.Plan2\x95\x12\n\x0e\x42illingService\x12\xa7\x01\n\x1a\x44\x65scribeBillingInformation\x12\x30.eolymp.universe.DescribeBillingInformationInput\x1a\x31.eolymp.universe.DescribeBillingInformationOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x0f\x12\r/billing/info\x12\xa1\x01\n\x18UpdateBillingInformation\x12..eolymp.universe.UpdateBillingInformationInput\x1a/.eolymp.universe.UpdateBillingInformationOutput\"$\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x0f\x1a\r/billing/info\x12\x9d\x01\n\x14\x44\x65scribeSubscription\x12*.eolymp.universe.DescribeSubscriptionInput\x1a+.eolymp.universe.DescribeSubscriptionOutput\",\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x17\x12\x15/billing/subscription\x12\x97\x01\n\x12\x43reateSubscription\x12(.eolymp.universe.CreateSubscriptionInput\x1a).eolymp.universe.CreateSubscriptionOutput\",\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x17\"\x15/billing/subscription\x12\x97\x01\n\x12UpdateSubscription\x12(.eolymp.universe.UpdateSubscriptionInput\x1a).eolymp.universe.UpdateSubscriptionOutput\",\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x17\x1a\x15/billing/subscription\x12\x97\x01\n\x12\x43\x61ncelSubscription\x12(.eolymp.universe.CancelSubscriptionInput\x1a).eolymp.universe.CancelSubscriptionOutput\",\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x17*\x15/billing/subscription\x12\xa2\x01\n\x16StartSubscriptionTrial\x12,.eolymp.universe.StartSubscriptionTrialInput\x1a-.eolymp.universe.StartSubscriptionTrialOutput\"+\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x16\"\x14/billing/trial/start\x12\x9a\x01\n\x14\x45ndSubscriptionTrial\x12*.eolymp.universe.EndSubscriptionTrialInput\x1a+.eolymp.universe.EndSubscriptionTrialOutput\")\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x14\"\x12/billing/trial/end\x12\xa6\x01\n\x14SimulateSubscription\x12*.eolymp.universe.SimulateSubscriptionInput\x1a+.eolymp.universe.SimulateSubscriptionOutput\"5\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02 \"\x1e/billing/subscription/simulate\x12\x90\x01\n\x10\x43reatePortalLink\x12&.eolymp.universe.CreatePortalLinkInput\x1a\'.eolymp.universe.CreatePortalLinkOutput\"+\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x16\"\x14/billing/portal-link\x12\x8a\x01\n\x0fUpcomingInvoice\x12%.eolymp.universe.UpcomingInvoiceInput\x1a&.eolymp.universe.UpcomingInvoiceOutput\"(\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x13\"\x11/billing/upcoming\x12\x96\x01\n\x0f\x44\x65scribeInvoice\x12%.eolymp.universe.DescribeInvoiceInput\x1a&.eolymp.universe.DescribeInvoiceOutput\"4\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1f\"\x1d/billing/invoice/{invoice_id}\x12\x8b\x01\n\nPayInvoice\x12 .eolymp.universe.PayInvoiceInput\x1a!.eolymp.universe.PayInvoiceOutput\"8\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\n\x82\xd3\xe4\x93\x02#\"!/billing/invoice/{invoice_id}/pay\x12\x81\x01\n\x0cListInvoices\x12\".eolymp.universe.ListInvoicesInput\x1a#.eolymp.universe.ListInvoicesOutput\"(\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x13\"\x11/billing/invoices\x12\x90\x01\n\x12ListAvailablePlans\x12(.eolymp.universe.ListAvailablePlansInput\x1a).eolymp.universe.ListAvailablePlansOutput\"%\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x10\"\x0e/billing/plansB3Z1github.com/eolymp/go-sdk/eolymp/universe;universeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.universe.billing_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/universe;universe'
  _globals['_BILLINGSERVICE'].methods_by_name['DescribeBillingInformation']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['DescribeBillingInformation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\017\022\r/billing/info'
  _globals['_BILLINGSERVICE'].methods_by_name['UpdateBillingInformation']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['UpdateBillingInformation']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\017\032\r/billing/info'
  _globals['_BILLINGSERVICE'].methods_by_name['DescribeSubscription']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['DescribeSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\027\022\025/billing/subscription'
  _globals['_BILLINGSERVICE'].methods_by_name['CreateSubscription']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['CreateSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\027\"\025/billing/subscription'
  _globals['_BILLINGSERVICE'].methods_by_name['UpdateSubscription']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['UpdateSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\027\032\025/billing/subscription'
  _globals['_BILLINGSERVICE'].methods_by_name['CancelSubscription']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['CancelSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\027*\025/billing/subscription'
  _globals['_BILLINGSERVICE'].methods_by_name['StartSubscriptionTrial']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['StartSubscriptionTrial']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\026\"\024/billing/trial/start'
  _globals['_BILLINGSERVICE'].methods_by_name['EndSubscriptionTrial']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['EndSubscriptionTrial']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\024\"\022/billing/trial/end'
  _globals['_BILLINGSERVICE'].methods_by_name['SimulateSubscription']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['SimulateSubscription']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002 \"\036/billing/subscription/simulate'
  _globals['_BILLINGSERVICE'].methods_by_name['CreatePortalLink']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['CreatePortalLink']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\026\"\024/billing/portal-link'
  _globals['_BILLINGSERVICE'].methods_by_name['UpcomingInvoice']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['UpcomingInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\023\"\021/billing/upcoming'
  _globals['_BILLINGSERVICE'].methods_by_name['DescribeInvoice']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['DescribeInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\037\"\035/billing/invoice/{invoice_id}'
  _globals['_BILLINGSERVICE'].methods_by_name['PayInvoice']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['PayInvoice']._serialized_options = b'\352\342\n\013\365\342\n\000\000\200?\370\342\n\n\202\323\344\223\002#\"!/billing/invoice/{invoice_id}/pay'
  _globals['_BILLINGSERVICE'].methods_by_name['ListInvoices']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['ListInvoices']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\023\"\021/billing/invoices'
  _globals['_BILLINGSERVICE'].methods_by_name['ListAvailablePlans']._loaded_options = None
  _globals['_BILLINGSERVICE'].methods_by_name['ListAvailablePlans']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\020\"\016/billing/plans'
  _globals['_DESCRIBEBILLINGINFORMATIONINPUT']._serialized_start=215
  _globals['_DESCRIBEBILLINGINFORMATIONINPUT']._serialized_end=248
  _globals['_DESCRIBEBILLINGINFORMATIONOUTPUT']._serialized_start=250
  _globals['_DESCRIBEBILLINGINFORMATIONOUTPUT']._serialized_end=336
  _globals['_UPDATEBILLINGINFORMATIONINPUT']._serialized_start=338
  _globals['_UPDATEBILLINGINFORMATIONINPUT']._serialized_end=421
  _globals['_UPDATEBILLINGINFORMATIONOUTPUT']._serialized_start=423
  _globals['_UPDATEBILLINGINFORMATIONOUTPUT']._serialized_end=455
  _globals['_DESCRIBESUBSCRIPTIONINPUT']._serialized_start=457
  _globals['_DESCRIBESUBSCRIPTIONINPUT']._serialized_end=484
  _globals['_DESCRIBESUBSCRIPTIONOUTPUT']._serialized_start=487
  _globals['_DESCRIBESUBSCRIPTIONOUTPUT']._serialized_end=628
  _globals['_CREATESUBSCRIPTIONINPUT']._serialized_start=630
  _globals['_CREATESUBSCRIPTIONINPUT']._serialized_end=707
  _globals['_CREATESUBSCRIPTIONOUTPUT']._serialized_start=709
  _globals['_CREATESUBSCRIPTIONOUTPUT']._serialized_end=757
  _globals['_UPDATESUBSCRIPTIONINPUT']._serialized_start=759
  _globals['_UPDATESUBSCRIPTIONINPUT']._serialized_end=836
  _globals['_UPDATESUBSCRIPTIONOUTPUT']._serialized_start=838
  _globals['_UPDATESUBSCRIPTIONOUTPUT']._serialized_end=864
  _globals['_CANCELSUBSCRIPTIONINPUT']._serialized_start=866
  _globals['_CANCELSUBSCRIPTIONINPUT']._serialized_end=891
  _globals['_CANCELSUBSCRIPTIONOUTPUT']._serialized_start=893
  _globals['_CANCELSUBSCRIPTIONOUTPUT']._serialized_end=919
  _globals['_STARTSUBSCRIPTIONTRIALINPUT']._serialized_start=921
  _globals['_STARTSUBSCRIPTIONTRIALINPUT']._serialized_end=987
  _globals['_STARTSUBSCRIPTIONTRIALOUTPUT']._serialized_start=989
  _globals['_STARTSUBSCRIPTIONTRIALOUTPUT']._serialized_end=1019
  _globals['_ENDSUBSCRIPTIONTRIALINPUT']._serialized_start=1021
  _globals['_ENDSUBSCRIPTIONTRIALINPUT']._serialized_end=1048
  _globals['_ENDSUBSCRIPTIONTRIALOUTPUT']._serialized_start=1050
  _globals['_ENDSUBSCRIPTIONTRIALOUTPUT']._serialized_end=1078
  _globals['_SIMULATESUBSCRIPTIONINPUT']._serialized_start=1080
  _globals['_SIMULATESUBSCRIPTIONINPUT']._serialized_end=1175
  _globals['_SIMULATESUBSCRIPTIONOUTPUT']._serialized_start=1177
  _globals['_SIMULATESUBSCRIPTIONOUTPUT']._serialized_end=1287
  _globals['_CREATEPORTALLINKINPUT']._serialized_start=1289
  _globals['_CREATEPORTALLINKINPUT']._serialized_end=1364
  _globals['_CREATEPORTALLINKOUTPUT']._serialized_start=1366
  _globals['_CREATEPORTALLINKOUTPUT']._serialized_end=1411
  _globals['_UPCOMINGINVOICEINPUT']._serialized_start=1413
  _globals['_UPCOMINGINVOICEINPUT']._serialized_end=1435
  _globals['_UPCOMINGINVOICEOUTPUT']._serialized_start=1437
  _globals['_UPCOMINGINVOICEOUTPUT']._serialized_end=1503
  _globals['_DESCRIBEINVOICEINPUT']._serialized_start=1505
  _globals['_DESCRIBEINVOICEINPUT']._serialized_end=1547
  _globals['_DESCRIBEINVOICEOUTPUT']._serialized_start=1549
  _globals['_DESCRIBEINVOICEOUTPUT']._serialized_end=1615
  _globals['_PAYINVOICEINPUT']._serialized_start=1617
  _globals['_PAYINVOICEINPUT']._serialized_end=1654
  _globals['_PAYINVOICEOUTPUT']._serialized_start=1656
  _globals['_PAYINVOICEOUTPUT']._serialized_end=1696
  _globals['_LISTINVOICESINPUT']._serialized_start=1698
  _globals['_LISTINVOICESINPUT']._serialized_end=1762
  _globals['_LISTINVOICESOUTPUT']._serialized_start=1764
  _globals['_LISTINVOICESOUTPUT']._serialized_end=1840
  _globals['_LISTAVAILABLEPLANSINPUT']._serialized_start=1843
  _globals['_LISTAVAILABLEPLANSINPUT']._serialized_end=1977
  _globals['_LISTAVAILABLEPLANSOUTPUT']._serialized_start=1979
  _globals['_LISTAVAILABLEPLANSOUTPUT']._serialized_end=2058
  _globals['_BILLINGSERVICE']._serialized_start=2061
  _globals['_BILLINGSERVICE']._serialized_end=4386
# @@protoc_insertion_point(module_scope)



from eolymp.l10n import term_pb2 as _term_pb2
from eolymp.l10n import translation_pb2 as _translation_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TranslationPair(_message.Message):
    __slots__ = ("term", "source", "translation", "suggestion")
    TERM_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    SUGGESTION_FIELD_NUMBER: _ClassVar[int]
    term: _term_pb2.Term
    source: _translation_pb2.Translation
    translation: _translation_pb2.Translation
    suggestion: _translation_pb2.Translation
    def __init__(self, term: _Optional[_Union[_term_pb2.Term, _Mapping]] = ..., source: _Optional[_Union[_translation_pb2.Translation, _Mapping]] = ..., translation: _Optional[_Union[_translation_pb2.Translation, _Mapping]] = ..., suggestion: _Optional[_Union[_translation_pb2.Translation, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor
SCOPE_FIELD_NUMBER: _ClassVar[int]
scope: _descriptor.FieldDescriptor

class Scope(_message.Message):
    __slots__ = ("scope",)
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    scope: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, scope: _Optional[_Iterable[str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/executor/stress_report.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/executor/stress_report.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.executor import stats_pb2 as eolymp_dot_executor_dot_stats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/executor/stress_report.proto\x12\x0f\x65olymp.executor\x1a\x1b\x65olymp/executor/stats.proto\"\x8d\x04\n\x0cStressReport\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x11\n\treference\x18\x02 \x01(\t\x12\x0e\n\x06origin\x18\x03 \x01(\t\x12=\n\x08metadata\x18\x05 \x03(\x0b\x32+.eolymp.executor.StressReport.MetadataEntry\x12\r\n\x05\x61gent\x18\x04 \x01(\t\x12/\n\x04runs\x18( \x03(\x0b\x32!.eolymp.executor.StressReport.Run\x12\x15\n\rerror_message\x18\x32 \x01(\t\x1a\x81\x02\n\x03Run\x12\x11\n\titeration\x18\x01 \x01(\r\x12\x38\n\x06status\x18\x02 \x01(\x0e\x32(.eolymp.executor.StressReport.Run.Status\x12\x11\n\tinput_url\x18\n \x01(\t\x12/\n\x0fgenerator_stats\x18\x14 \x01(\x0b\x32\x16.eolymp.executor.Stats\x12.\n\x0esolution_stats\x18\x15 \x01(\x0b\x32\x16.eolymp.executor.Stats\"9\n\x06Status\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08\x43OMPLETE\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x33Z1github.com/eolymp/go-sdk/eolymp/executor;executorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.executor.stress_report_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/eolymp/go-sdk/eolymp/executor;executor'
  _globals['_STRESSREPORT_METADATAENTRY']._loaded_options = None
  _globals['_STRESSREPORT_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_STRESSREPORT']._serialized_start=86
  _globals['_STRESSREPORT']._serialized_end=611
  _globals['_STRESSREPORT_RUN']._serialized_start=305
  _globals['_STRESSREPORT_RUN']._serialized_end=562
  _globals['_STRESSREPORT_RUN_STATUS']._serialized_start=505
  _globals['_STRESSREPORT_RUN_STATUS']._serialized_end=562
  _globals['_STRESSREPORT_METADATAENTRY']._serialized_start=564
  _globals['_STRESSREPORT_METADATAENTRY']._serialized_end=611
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.discussion import subscription_pb2 as _subscription_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescribeSubscriptionInput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeSubscriptionOutput(_message.Message):
    __slots__ = ("subscription",)
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    subscription: _subscription_pb2.Subscription
    def __init__(self, subscription: _Optional[_Union[_subscription_pb2.Subscription, _Mapping]] = ...) -> None: ...

class UpdateSubscriptionInput(_message.Message):
    __slots__ = ("subscription",)
    SUBSCRIPTION_FIELD_NUMBER: _ClassVar[int]
    subscription: _subscription_pb2.Subscription
    def __init__(self, subscription: _Optional[_Union[_subscription_pb2.Subscription, _Mapping]] = ...) -> None: ...

class UpdateSubscriptionOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.l10n import term_pb2 as _term_pb2
from eolymp.l10n import translation_pb2 as _translation_pb2
from eolymp.l10n import translation_pair_pb2 as _translation_pair_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateTermInput(_message.Message):
    __slots__ = ("term",)
    TERM_FIELD_NUMBER: _ClassVar[int]
    term: _term_pb2.Term
    def __init__(self, term: _Optional[_Union[_term_pb2.Term, _Mapping]] = ...) -> None: ...

class CreateTermOutput(_message.Message):
    __slots__ = ("term_id",)
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    def __init__(self, term_id: _Optional[str] = ...) -> None: ...

class ImportTermsInput(_message.Message):
    __slots__ = ("terms",)
    TERMS_FIELD_NUMBER: _ClassVar[int]
    terms: _containers.RepeatedCompositeFieldContainer[_term_pb2.Term]
    def __init__(self, terms: _Optional[_Iterable[_Union[_term_pb2.Term, _Mapping]]] = ...) -> None: ...

class ImportTermsOutput(_message.Message):
    __slots__ = ("created_count", "updated_count", "deprecated_count")
    CREATED_COUNT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_COUNT_FIELD_NUMBER: _ClassVar[int]
    DEPRECATED_COUNT_FIELD_NUMBER: _ClassVar[int]
    created_count: int
    updated_count: int
    deprecated_count: int
    def __init__(self, created_count: _Optional[int] = ..., updated_count: _Optional[int] = ..., deprecated_count: _Optional[int] = ...) -> None: ...

class ListTermsInput(_message.Message):
    __slots__ = ("offset", "size", "filters")
    class ExpressionTranslation(_message.Message):
        __slots__ = ("locale", "status")
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        locale: str
        status: _expression_pb2.ExpressionEnum
        def __init__(self, locale: _Optional[str] = ..., status: _Optional[_Union[_expression_pb2.ExpressionEnum, _Mapping]] = ...) -> None: ...
    class Filter(_message.Message):
        __slots__ = ("query", "id", "key", "message", "status", "translation")
        QUERY_FIELD_NUMBER: _ClassVar[int]
        ID_FIELD_NUMBER: _ClassVar[int]
        KEY_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        TRANSLATION_FIELD_NUMBER: _ClassVar[int]
        query: str
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        key: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        message: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        translation: _containers.RepeatedCompositeFieldContainer[ListTermsInput.ExpressionTranslation]
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., key: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., message: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., translation: _Optional[_Iterable[_Union[ListTermsInput.ExpressionTranslation, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListTermsInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListTermsInput.Filter, _Mapping]] = ...) -> None: ...

class ListTermsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_term_pb2.Term]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_term_pb2.Term, _Mapping]]] = ...) -> None: ...

class UpdateTermInput(_message.Message):
    __slots__ = ("term_id", "term")
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    TERM_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    term: _term_pb2.Term
    def __init__(self, term_id: _Optional[str] = ..., term: _Optional[_Union[_term_pb2.Term, _Mapping]] = ...) -> None: ...

class UpdateTermOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RestoreTermInput(_message.Message):
    __slots__ = ("term_id",)
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    def __init__(self, term_id: _Optional[str] = ...) -> None: ...

class RestoreTermOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeprecateTermInput(_message.Message):
    __slots__ = ("term_id",)
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    def __init__(self, term_id: _Optional[str] = ...) -> None: ...

class DeprecateTermOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteTermInput(_message.Message):
    __slots__ = ("term_id",)
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    def __init__(self, term_id: _Optional[str] = ...) -> None: ...

class DeleteTermOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeTermInput(_message.Message):
    __slots__ = ("term_id",)
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    def __init__(self, term_id: _Optional[str] = ...) -> None: ...

class DescribeTermOutput(_message.Message):
    __slots__ = ("term",)
    TERM_FIELD_NUMBER: _ClassVar[int]
    term: _term_pb2.Term
    def __init__(self, term: _Optional[_Union[_term_pb2.Term, _Mapping]] = ...) -> None: ...

class AddLocaleInput(_message.Message):
    __slots__ = ("locale_code",)
    LOCALE_CODE_FIELD_NUMBER: _ClassVar[int]
    locale_code: str
    def __init__(self, locale_code: _Optional[str] = ...) -> None: ...

class AddLocaleOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RemoveLocaleInput(_message.Message):
    __slots__ = ("locale_code",)
    LOCALE_CODE_FIELD_NUMBER: _ClassVar[int]
    locale_code: str
    def __init__(self, locale_code: _Optional[str] = ...) -> None: ...

class RemoveLocaleOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ListLocalesInput(_message.Message):
    __slots__ = ("offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("code", "ready")
        CODE_FIELD_NUMBER: _ClassVar[int]
        READY_FIELD_NUMBER: _ClassVar[int]
        code: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        ready: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionBool]
        def __init__(self, code: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., ready: _Optional[_Iterable[_Union[_expression_pb2.ExpressionBool, _Mapping]]] = ...) -> None: ...
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    offset: int
    size: int
    filters: ListLocalesInput.Filter
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListLocalesInput.Filter, _Mapping]] = ...) -> None: ...

class ListLocalesOutput(_message.Message):
    __slots__ = ("total", "items")
    class Locale(_message.Message):
        __slots__ = ("code", "ready", "translated_terms", "missing_terms", "total_terms")
        CODE_FIELD_NUMBER: _ClassVar[int]
        READY_FIELD_NUMBER: _ClassVar[int]
        TRANSLATED_TERMS_FIELD_NUMBER: _ClassVar[int]
        MISSING_TERMS_FIELD_NUMBER: _ClassVar[int]
        TOTAL_TERMS_FIELD_NUMBER: _ClassVar[int]
        code: str
        ready: bool
        translated_terms: int
        missing_terms: int
        total_terms: int
        def __init__(self, code: _Optional[str] = ..., ready: bool = ..., translated_terms: _Optional[int] = ..., missing_terms: _Optional[int] = ..., total_terms: _Optional[int] = ...) -> None: ...
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[ListLocalesOutput.Locale]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[ListLocalesOutput.Locale, _Mapping]]] = ...) -> None: ...

class TranslateTermInput(_message.Message):
    __slots__ = ("term_id", "translation")
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    translation: _translation_pb2.Translation
    def __init__(self, term_id: _Optional[str] = ..., translation: _Optional[_Union[_translation_pb2.Translation, _Mapping]] = ...) -> None: ...

class TranslateTermOutput(_message.Message):
    __slots__ = ("translation_id",)
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    translation_id: str
    def __init__(self, translation_id: _Optional[str] = ...) -> None: ...

class ListTranslationsInput(_message.Message):
    __slots__ = ("term_id", "offset", "size", "filters")
    class Filter(_message.Message):
        __slots__ = ("id", "message", "status", "locale")
        ID_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        LOCALE_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        message: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        locale: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        def __init__(self, id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., message: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., locale: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ...) -> None: ...
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    offset: int
    size: int
    filters: ListTranslationsInput.Filter
    def __init__(self, term_id: _Optional[str] = ..., offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListTranslationsInput.Filter, _Mapping]] = ...) -> None: ...

class ListTranslationsOutput(_message.Message):
    __slots__ = ("total", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    items: _containers.RepeatedCompositeFieldContainer[_translation_pb2.Translation]
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_translation_pb2.Translation, _Mapping]]] = ...) -> None: ...

class SuggestTranslationInput(_message.Message):
    __slots__ = ("term_id", "locale")
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    locale: str
    def __init__(self, term_id: _Optional[str] = ..., locale: _Optional[str] = ...) -> None: ...

class SuggestTranslationOutput(_message.Message):
    __slots__ = ("messages",)
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, messages: _Optional[_Iterable[str]] = ...) -> None: ...

class UpdateTranslationInput(_message.Message):
    __slots__ = ("term_id", "translation_id", "translation")
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    translation_id: str
    translation: _translation_pb2.Translation
    def __init__(self, term_id: _Optional[str] = ..., translation_id: _Optional[str] = ..., translation: _Optional[_Union[_translation_pb2.Translation, _Mapping]] = ...) -> None: ...

class UpdateTranslationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class ApproveTranslationInput(_message.Message):
    __slots__ = ("term_id", "translation_id")
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    translation_id: str
    def __init__(self, term_id: _Optional[str] = ..., translation_id: _Optional[str] = ...) -> None: ...

class ApproveTranslationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class RejectTranslationInput(_message.Message):
    __slots__ = ("term_id", "translation_id")
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    translation_id: str
    def __init__(self, term_id: _Optional[str] = ..., translation_id: _Optional[str] = ...) -> None: ...

class RejectTranslationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DeleteTranslationInput(_message.Message):
    __slots__ = ("term_id", "translation_id")
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ID_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    translation_id: str
    def __init__(self, term_id: _Optional[str] = ..., translation_id: _Optional[str] = ...) -> None: ...

class DeleteTranslationOutput(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DescribeTranslationInput(_message.Message):
    __slots__ = ("term_id",)
    TERM_ID_FIELD_NUMBER: _ClassVar[int]
    term_id: str
    def __init__(self, term_id: _Optional[str] = ...) -> None: ...

class DescribeTranslationOutput(_message.Message):
    __slots__ = ("term",)
    TERM_FIELD_NUMBER: _ClassVar[int]
    term: _term_pb2.Term
    def __init__(self, term: _Optional[_Union[_term_pb2.Term, _Mapping]] = ...) -> None: ...

class ImportTranslationsInput(_message.Message):
    __slots__ = ("locale", "translations")
    class TranslationsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    TRANSLATIONS_FIELD_NUMBER: _ClassVar[int]
    locale: str
    translations: _containers.ScalarMap[str, str]
    def __init__(self, locale: _Optional[str] = ..., translations: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ImportTranslationsOutput(_message.Message):
    __slots__ = ("created_count",)
    CREATED_COUNT_FIELD_NUMBER: _ClassVar[int]
    created_count: int
    def __init__(self, created_count: _Optional[int] = ...) -> None: ...

class ExportTranslationsInput(_message.Message):
    __slots__ = ("locale",)
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    locale: str
    def __init__(self, locale: _Optional[str] = ...) -> None: ...

class ExportTranslationsOutput(_message.Message):
    __slots__ = ("translations",)
    class TranslationsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    TRANSLATIONS_FIELD_NUMBER: _ClassVar[int]
    translations: _containers.ScalarMap[str, str]
    def __init__(self, translations: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ListTranslationPairsInput(_message.Message):
    __slots__ = ("locale", "source", "size", "offset", "after", "before", "filters")
    class Filter(_message.Message):
        __slots__ = ("query", "term_key", "term_status", "source_message", "translation_status", "translation_message")
        QUERY_FIELD_NUMBER: _ClassVar[int]
        TERM_KEY_FIELD_NUMBER: _ClassVar[int]
        TERM_STATUS_FIELD_NUMBER: _ClassVar[int]
        SOURCE_MESSAGE_FIELD_NUMBER: _ClassVar[int]
        TRANSLATION_STATUS_FIELD_NUMBER: _ClassVar[int]
        TRANSLATION_MESSAGE_FIELD_NUMBER: _ClassVar[int]
        query: str
        term_key: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        term_status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        source_message: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        translation_status: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionEnum]
        translation_message: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        def __init__(self, query: _Optional[str] = ..., term_key: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., term_status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., source_message: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ..., translation_status: _Optional[_Iterable[_Union[_expression_pb2.ExpressionEnum, _Mapping]]] = ..., translation_message: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    AFTER_FIELD_NUMBER: _ClassVar[int]
    BEFORE_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    locale: str
    source: str
    size: int
    offset: int
    after: str
    before: str
    filters: ListTranslationPairsInput.Filter
    def __init__(self, locale: _Optional[str] = ..., source: _Optional[str] = ..., size: _Optional[int] = ..., offset: _Optional[int] = ..., after: _Optional[str] = ..., before: _Optional[str] = ..., filters: _Optional[_Union[ListTranslationPairsInput.Filter, _Mapping]] = ...) -> None: ...

class ListTranslationPairsOutput(_message.Message):
    __slots__ = ("total", "has_more", "items")
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    HAS_MORE_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    total: int
    has_more: bool
    items: _containers.RepeatedCompositeFieldContainer[_translation_pair_pb2.TranslationPair]
    def __init__(self, total: _Optional[int] = ..., has_more: bool = ..., items: _Optional[_Iterable[_Union[_translation_pair_pb2.TranslationPair, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: eolymp/community/member_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'eolymp/community/member_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import member_pb2 as eolymp_dot_community_dot_member__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/community/member_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/community/member.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"g\n\x12MemberChangedEvent\x12(\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\x12\'\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x18.eolymp.community.Member\"=\n\x11\x43reateMemberInput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\'\n\x12\x43reateMemberOutput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\xc5\x04\n\x11UpdateMemberInput\x12\x38\n\x05patch\x18\x01 \x03(\x0e\x32).eolymp.community.UpdateMemberInput.Patch\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12(\n\x06member\x18\x03 \x01(\x0b\x32\x18.eolymp.community.Member\"\xb8\x03\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0c\n\x08INACTIVE\x10\x01\x12\x0e\n\nUNOFFICIAL\x10\x02\x12\n\n\x06GROUPS\x10\x03\x12\x0e\n\nGROUPS_ADD\x10\x04\x12\x11\n\rGROUPS_REMOVE\x10\x05\x12\x0b\n\x07\x41\x43\x43OUNT\x10\x64\x12\x11\n\rUSER_NICKNAME\x10\x65\x12\x0e\n\nUSER_EMAIL\x10\x66\x12\x11\n\rUSER_PASSWORD\x10g\x12\r\n\tUSER_NAME\x10h\x12\x10\n\x0cUSER_PICTURE\x10i\x12\x11\n\rUSER_BIRTHDAY\x10j\x12\x10\n\x0cUSER_COUNTRY\x10k\x12\r\n\tUSER_CITY\x10l\x12\x14\n\x10USER_PREFERENCES\x10m\x12\x1c\n\x17USER_PREFERENCES_LOCALE\x10\xbe\x01\x12\x1e\n\x19USER_PREFERENCES_TIMEZONE\x10\xbf\x01\x12\x1d\n\x18USER_PREFERENCES_RUNTIME\x10\xc0\x01\x12\x1c\n\x18USER_EMAIL_SUBSCRIPTIONS\x10n\x12\x0e\n\tTEAM_NAME\x10\xc8\x01\x12\x0f\n\nGHOST_NAME\x10\xac\x02\x12\x0f\n\nATTRIBUTES\x10\x84\x07\"\x14\n\x12UpdateMemberOutput\"\x7f\n\x18UpdateMemberPictureInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x10\n\x08offset_x\x18\n \x01(\r\x12\x10\n\x08offset_y\x18\x0b \x01(\r\x12\x0c\n\x04size\x18\x0c \x01(\r\"0\n\x19UpdateMemberPictureOutput\x12\x13\n\x0bpicture_url\x18\x01 \x01(\t\"<\n\x11\x44\x65leteMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12\x14\n\x0c\x66orce_delete\x18\x02 \x01(\x08\"\x14\n\x12\x44\x65leteMemberOutput\"\'\n\x12RestoreMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\"\x15\n\x13RestoreMemberOutput\"X\n\x13\x44\x65scribeMemberInput\x12\x11\n\tmember_id\x18\x01 \x01(\t\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.community.Member.Extra\"@\n\x14\x44\x65scribeMemberOutput\x12(\n\x06member\x18\x01 \x01(\x0b\x32\x18.eolymp.community.Member\"\xcf\x0b\n\x10ListMembersInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.community.ListMembersInput.Filter\x12\x0e\n\x06search\x18) \x01(\t\x12\x39\n\x04sort\x18\x32 \x01(\x0e\x32+.eolymp.community.ListMembersInput.Sortable\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.community.Member.Extra\x1a\x91\x01\n\x13\x45xpressionAttribute\x12\x15\n\rattribute_key\x18\x01 \x01(\t\x12/\n\x06number\x18\n \x01(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12\x32\n\x06string\x18\x0b \x01(\x0b\x32\".eolymp.wellknown.ExpressionString\x1a\xd5\x07\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x04type\x18\x02 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x38\n\x0c\x64isplay_name\x18\x03 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x32\n\x08inactive\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x34\n\nincomplete\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x34\n\nunofficial\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x06seated\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12/\n\x07team_id\x18\x07 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x08group_id\x18\x08 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x37\n\x0buser_issuer\x18\x65 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x38\n\x0cuser_subject\x18\x66 \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x36\n\nuser_email\x18g \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x35\n\tuser_name\x18h \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x39\n\ruser_nickname\x18i \x03(\x0b\x32\".eolymp.wellknown.ExpressionString\x12\x37\n\x08\x62irthday\x18l \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12/\n\x07\x63ountry\x18m \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12.\n\x05score\x18j \x03(\x0b\x32\x1f.eolymp.wellknown.ExpressionInt\x12I\n\tattribute\x18k \x03(\x0b\x32\x36.eolymp.community.ListMembersInput.ExpressionAttribute\"N\n\x08Sortable\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x10\n\x0c\x44ISPLAY_NAME\x10\x01\x12\x0e\n\nCREATED_AT\x10\x02\x12\x08\n\x04TYPE\x10\x03\x12\t\n\x05SCORE\x10\x04\"K\n\x11ListMembersOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.community.Member\"7\n\x11\x41ssignMemberInput\x12\x0f\n\x07team_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"\x14\n\x12\x41ssignMemberOutput\"9\n\x13UnassignMemberInput\x12\x0f\n\x07team_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"\x16\n\x14UnassignMemberOutput\"|\n\x18\x44\x65scribeMemberUsageInput\x12\x30\n\x0cperiod_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nperiod_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"_\n\x19\x44\x65scribeMemberUsageOutput\x12\x15\n\rtotal_members\x18\x01 \x01(\r\x12\x16\n\x0e\x61\x63tive_members\x18\x02 \x01(\r\x12\x13\n\x0bnew_members\x18\x03 \x01(\r2\xda\r\n\rMemberService\x12\x98\x01\n\x0c\x43reateMember\x12#.eolymp.community.CreateMemberInput\x1a$.eolymp.community.CreateMemberOutput\"=\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\n\"\x08/members\x12\xa4\x01\n\x0cUpdateMember\x12#.eolymp.community.UpdateMemberInput\x1a$.eolymp.community.UpdateMemberOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x16\"\x14/members/{member_id}\x12\xc1\x01\n\x13UpdateMemberPicture\x12*.eolymp.community.UpdateMemberPictureInput\x1a+.eolymp.community.UpdateMemberPictureOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x1e\"\x1c/members/{member_id}/picture\x12\xa4\x01\n\x0c\x44\x65leteMember\x12#.eolymp.community.DeleteMemberInput\x1a$.eolymp.community.DeleteMemberOutput\"I\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x16*\x14/members/{member_id}\x12\xaf\x01\n\rRestoreMember\x12$.eolymp.community.RestoreMemberInput\x1a%.eolymp.community.RestoreMemberOutput\"Q\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02\x1e\"\x1c/members/{member_id}/restore\x12\xa9\x01\n\x0e\x44\x65scribeMember\x12%.eolymp.community.DescribeMemberInput\x1a&.eolymp.community.DescribeMemberOutput\"H\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x16\x12\x14/members/{member_id}\x12\x94\x01\n\x0bListMembers\x12\".eolymp.community.ListMembersInput\x1a#.eolymp.community.ListMembersOutput\"<\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\n\x12\x08/members\x12\xb4\x01\n\x0c\x41ssignMember\x12#.eolymp.community.AssignMemberInput\x1a$.eolymp.community.AssignMemberOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02&\x1a$/members/{team_id}/users/{member_id}\x12\xba\x01\n\x0eUnassignMember\x12%.eolymp.community.UnassignMemberInput\x1a&.eolymp.community.UnassignMemberOutput\"Y\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x1a\x8a\xe3\n\x16\x63ommunity:member:write\x82\xd3\xe4\x93\x02&*$/members/{team_id}/users/{member_id}\x12\xb2\x01\n\x13\x44\x65scribeMemberUsage\x12*.eolymp.community.DescribeMemberUsageInput\x1a+.eolymp.community.DescribeMemberUsageOutput\"B\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xe3\n\x19\x8a\xe3\n\x15\x63ommunity:member:read\x82\xd3\xe4\x93\x02\x10\x12\x0e/usage/membersB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.member_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _globals['_MEMBERSERVICE'].methods_by_name['CreateMember']._loaded_options = None
  _globals['_MEMBERSERVICE'].methods_by_name['CreateMember']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\n\"\010/members'
  _globals['_MEMBERSERVICE'].methods_by_name['UpdateMember']._loaded_options = None
  _globals['_MEMBERSERVICE'].methods_by_name['UpdateMember']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\026\"\024/members/{member_id}'
  _globals['_MEMBERSERVICE'].methods_by_name['UpdateMemberPicture']._loaded_options = None
  _globals['_MEMBERSERVICE'].methods_by_name['UpdateMemberPicture']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\036\"\034/members/{member_id}/picture'
  _globals['_MEMBERSERVICE'].methods_by_name['DeleteMember']._loaded_options = None
  _globals['_MEMBERSERVICE'].methods_by_name['DeleteMember']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\026*\024/members/{member_id}'
  _globals['_MEMBERSERVICE'].methods_by_name['RestoreMember']._loaded_options = None
  _globals['_MEMBERSERVICE'].methods_by_name['RestoreMember']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002\036\"\034/members/{member_id}/restore'
  _globals['_MEMBERSERVICE'].methods_by_name['DescribeMember']._loaded_options = None
  _globals['_MEMBERSERVICE'].methods_by_name['DescribeMember']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\026\022\024/members/{member_id}'
  _globals['_MEMBERSERVICE'].methods_by_name['ListMembers']._loaded_options = None
  _globals['_MEMBERSERVICE'].methods_by_name['ListMembers']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\n\022\010/members'
  _globals['_MEMBERSERVICE'].methods_by_name['AssignMember']._loaded_options = None
  _globals['_MEMBERSERVICE'].methods_by_name['AssignMember']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002&\032$/members/{team_id}/users/{member_id}'
  _globals['_MEMBERSERVICE'].methods_by_name['UnassignMember']._loaded_options = None
  _globals['_MEMBERSERVICE'].methods_by_name['UnassignMember']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\032\212\343\n\026community:member:write\202\323\344\223\002&*$/members/{team_id}/users/{member_id}'
  _globals['_MEMBERSERVICE'].methods_by_name['DescribeMemberUsage']._loaded_options = None
  _globals['_MEMBERSERVICE'].methods_by_name['DescribeMemberUsage']._serialized_options = b'\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\343\n\031\212\343\n\025community:member:read\202\323\344\223\002\020\022\016/usage/members'
  _globals['_MEMBERCHANGEDEVENT']._serialized_start=291
  _globals['_MEMBERCHANGEDEVENT']._serialized_end=394
  _globals['_CREATEMEMBERINPUT']._serialized_start=396
  _globals['_CREATEMEMBERINPUT']._serialized_end=457
  _globals['_CREATEMEMBEROUTPUT']._serialized_start=459
  _globals['_CREATEMEMBEROUTPUT']._serialized_end=498
  _globals['_UPDATEMEMBERINPUT']._serialized_start=501
  _globals['_UPDATEMEMBERINPUT']._serialized_end=1082
  _globals['_UPDATEMEMBERINPUT_PATCH']._serialized_start=642
  _globals['_UPDATEMEMBERINPUT_PATCH']._serialized_end=1082
  _globals['_UPDATEMEMBEROUTPUT']._serialized_start=1084
  _globals['_UPDATEMEMBEROUTPUT']._serialized_end=1104
  _globals['_UPDATEMEMBERPICTUREINPUT']._serialized_start=1106
  _globals['_UPDATEMEMBERPICTUREINPUT']._serialized_end=1233
  _globals['_UPDATEMEMBERPICTUREOUTPUT']._serialized_start=1235
  _globals['_UPDATEMEMBERPICTUREOUTPUT']._serialized_end=1283
  _globals['_DELETEMEMBERINPUT']._serialized_start=1285
  _globals['_DELETEMEMBERINPUT']._serialized_end=1345
  _globals['_DELETEMEMBEROUTPUT']._serialized_start=1347
  _globals['_DELETEMEMBEROUTPUT']._serialized_end=1367
  _globals['_RESTOREMEMBERINPUT']._serialized_start=1369
  _globals['_RESTOREMEMBERINPUT']._serialized_end=1408
  _globals['_RESTOREMEMBEROUTPUT']._serialized_start=1410
  _globals['_RESTOREMEMBEROUTPUT']._serialized_end=1431
  _globals['_DESCRIBEMEMBERINPUT']._serialized_start=1433
  _globals['_DESCRIBEMEMBERINPUT']._serialized_end=1521
  _globals['_DESCRIBEMEMBEROUTPUT']._serialized_start=1523
  _globals['_DESCRIBEMEMBEROUTPUT']._serialized_end=1587
  _globals['_LISTMEMBERSINPUT']._serialized_start=1590
  _globals['_LISTMEMBERSINPUT']._serialized_end=3077
  _globals['_LISTMEMBERSINPUT_EXPRESSIONATTRIBUTE']._serialized_start=1868
  _globals['_LISTMEMBERSINPUT_EXPRESSIONATTRIBUTE']._serialized_end=2013
  _globals['_LISTMEMBERSINPUT_FILTER']._serialized_start=2016
  _globals['_LISTMEMBERSINPUT_FILTER']._serialized_end=2997
  _globals['_LISTMEMBERSINPUT_SORTABLE']._serialized_start=2999
  _globals['_LISTMEMBERSINPUT_SORTABLE']._serialized_end=3077
  _globals['_LISTMEMBERSOUTPUT']._serialized_start=3079
  _globals['_LISTMEMBERSOUTPUT']._serialized_end=3154
  _globals['_ASSIGNMEMBERINPUT']._serialized_start=3156
  _globals['_ASSIGNMEMBERINPUT']._serialized_end=3211
  _globals['_ASSIGNMEMBEROUTPUT']._serialized_start=3213
  _globals['_ASSIGNMEMBEROUTPUT']._serialized_end=3233
  _globals['_UNASSIGNMEMBERINPUT']._serialized_start=3235
  _globals['_UNASSIGNMEMBERINPUT']._serialized_end=3292
  _globals['_UNASSIGNMEMBEROUTPUT']._serialized_start=3294
  _globals['_UNASSIGNMEMBEROUTPUT']._serialized_end=3316
  _globals['_DESCRIBEMEMBERUSAGEINPUT']._serialized_start=3318
  _globals['_DESCRIBEMEMBERUSAGEINPUT']._serialized_end=3442
  _globals['_DESCRIBEMEMBERUSAGEOUTPUT']._serialized_start=3444
  _globals['_DESCRIBEMEMBERUSAGEOUTPUT']._serialized_end=3539
  _globals['_MEMBERSERVICE']._serialized_start=3542
  _globals['_MEMBERSERVICE']._serialized_end=5296
# @@protoc_insertion_point(module_scope)
